@@ -433,41 +433,41 @@ SHAFinal( char *key, SHA_CTX *shaInfo )
 struct _GSHA
 {
   SHA_CTX	ctx;
-  guchar 	digest[GNET_SHA_HASH_LENGTH];
+  gchar 	digest[GNET_SHA_HASH_LENGTH];
 };
 
 
 /**
  *  gnet_sha_new:
- *  @buffer: Buffer to hash
- *  @length: Length of that buffer
+ *  @buffer: buffer to hash
+ *  @length: length of @buffer
  * 
- *  Create an SHA hash of the buffer.
+ *  Creates a #GSHA from @buffer.
  *
  *  Returns: a new #GSHA.
  *
  **/
 GSHA*           
-gnet_sha_new (const guint8* buffer, guint length)
+gnet_sha_new (const gchar* buffer, guint length)
 {
-  GSHA* gsha;
+  GSHA* sha;
 
-  gsha = g_new0 (GSHA, 1);
-  SHAInit (&gsha->ctx);
-  SHAUpdate (&gsha->ctx, buffer, length);
-  SHAFinal ((gpointer) &gsha->digest, &gsha->ctx);
+  sha = g_new0 (GSHA, 1);
+  SHAInit (&sha->ctx);
+  SHAUpdate (&sha->ctx, buffer, length);
+  SHAFinal ((gpointer) &sha->digest, &sha->ctx);
 
-  return gsha;
+  return sha;
 }
 
 
 
 /**
  *  gnet_sha_new_string:
- *  @str: Hexidecimal string
+ *  @str: hexidecimal string
  * 
- *  Create an SHA hash from a hexidecimal string.  The string must be
- *  of length greater than or equal to %GNET_SHA_HASH_LENGTH * 2.
+ *  Createss a #GSHA from @str.  @str is a hexidecimal string
+ *  representing the digest.
  *
  *  Returns: a new #GSHA.
  *
@@ -475,13 +475,13 @@ gnet_sha_new (const guint8* buffer, guint length)
 GSHA*		
 gnet_sha_new_string (const gchar* str)
 {
-  GSHA* gsha;
+  GSHA* sha;
   guint i;
 
   g_return_val_if_fail (str, NULL);
   g_return_val_if_fail (strlen(str) == (GNET_SHA_HASH_LENGTH * 2), NULL);
 
-  gsha = g_new0 (GSHA, 1);
+  sha = g_new0 (GSHA, 1);
 
   for (i = 0; i < (GNET_SHA_HASH_LENGTH * 2); ++i)
     {
@@ -516,53 +516,53 @@ gnet_sha_new_string (const gchar* str)
 	}
 
       if (i % 2)
-	gsha->digest[i / 2] |= val;
+	sha->digest[i / 2] |= val;
       else
-	gsha->digest[i / 2] = val << 4;
+	sha->digest[i / 2] = val << 4;
     }
 
-  return gsha;
+  return sha;
 }
 
 
 
 /**
- *  gnet_sha_clone:
- *  @gsha: SHA to clone.
+ *  gnet_sha_clone
+ *  @sha: a #GSHA
  * 
- *  Create a SHA from another one.
+ *  Copies a #GSHA.
  *
- *  Returns: a new #GSHA.
+ *  Returns: a copy of @sha.
  *
  **/
 GSHA*           
-gnet_sha_clone (const GSHA* gsha)
+gnet_sha_clone (const GSHA* sha)
 {
-  GSHA* gsha2;
+  GSHA* sha2;
 
-  g_return_val_if_fail (gsha, NULL);
+  g_return_val_if_fail (sha, NULL);
 
-  gsha2      = g_new0 (GSHA, 1);
-  gsha2->ctx = gsha->ctx;
-  memcpy (gsha2->digest, gsha->digest, sizeof(gsha->digest));
+  sha2      = g_new0 (GSHA, 1);
+  sha2->ctx = sha->ctx;
+  memcpy (sha2->digest, sha->digest, sizeof(sha->digest));
 
-  return gsha2;
+  return sha2;
 }
 
 
 
 /** 
- *  gnet_sha_delete:
- *  @gsha: #GSHA to delete
+ *  gnet_sha_delete
+ *  @sha: a #GSHA
  *
- *  Delete a #GSHA.
+ *  Deletes a #GSHA.
  *
  **/
 void
-gnet_sha_delete (GSHA* gsha)
+gnet_sha_delete (GSHA* sha)
 {
-  if (gsha)
-    g_free (gsha);
+  if (sha)
+    g_free (sha);
 }
 
 
@@ -570,59 +570,60 @@ gnet_sha_delete (GSHA* gsha)
 
 
 /**
- *  gnet_sha_new_incremental:
+ *  gnet_sha_new_incremental
  *
- *  Create a SHA hash in incremental mode.  After creating the #GSHA, call
- *  gnet_sha_update() and gnet_sha_final().
+ *  Creates a #GSHA incrementally.  After creating a #GSHA, call
+ *  gnet_sha_update() one or more times to hash data.  Finally, call
+ *  gnet_sha_final() to compute the final hash value.
  *
- *  Returns: new GSHA
+ *  Returns: a new #GSHA.
  *
  **/
 GSHA*		
 gnet_sha_new_incremental (void)
 {
-  GSHA* gsha;
+  GSHA* sha;
 
-  gsha = g_new0 (GSHA, 1);
-  SHAInit (&gsha->ctx);
-  return gsha;
+  sha = g_new0 (GSHA, 1);
+  SHAInit (&sha->ctx);
+  return sha;
 }
 
 
 /**
- *  gnet_sha_update:
- *  @gsha: #GSHA to update
- *  @buffer: Buffer to add
- *  @length: Length of that buffer
+ *  gnet_sha_update
+ *  @sha: a #GSHA
+ *  @buffer: buffer to add
+ *  @length: length of @buffer
  *
- *  Update the hash with buffer.  This may be called several times on
- *  an incremental hash before being finalized.
+ *  Updates the hash with @buffer.  This may be called several times
+ *  on a hash created by gnet_sha_new_incremental() before being
+ *  finalized by calling gnet_sha_final().
  * 
  **/
 void
-gnet_sha_update (GSHA* gsha, const guchar* buffer, guint length)
+gnet_sha_update (GSHA* sha, const gchar* buffer, guint length)
 {
-  g_return_if_fail (gsha);
+  g_return_if_fail (sha);
 
-  SHAUpdate (&gsha->ctx, buffer, length);
+  SHAUpdate (&sha->ctx, buffer, length);
 }
 
 
 /**
- *  gnet_sha_final:
- *  @gsha: #GSHA to finalize
+ *  gnet_sha_final
+ *  @sha: a #GSHA
  *
- *  Calcuate the final hash value.  This is called on a #GSHA created
- *  using gnet_sha_new_incremental() and updated using gnet_sha_update()
- *  possibly several times.  
+ *  Calcuates the final hash value of a #GSHA.  This should only be
+ *  called on a #GSHA created by gnet_sha_new_incremental().
  *
  **/
 void
-gnet_sha_final (GSHA* gsha)
+gnet_sha_final (GSHA* sha)
 {
-  g_return_if_fail (gsha);
+  g_return_if_fail (sha);
 
-  SHAFinal ((gpointer) &gsha->digest, &gsha->ctx);
+  SHAFinal ((gpointer) &sha->digest, &sha->ctx);
 }
 
 
@@ -630,71 +631,21 @@ gnet_sha_final (GSHA* gsha)
 /* **************************************** */
 
 /**
- *  gnet_sha_equal:
- *  @p1: Pointer to first #GSHA.
- *  @p2: Pointer to second #GSHA.
+ *  gnet_sha_get_digest
+ *  @sha: a #GSHA
  *
- *  Compare two #GSHA's.  
+ *  Gets the raw SHA digest.
  *
- *  Returns: 1 if they are the same; 0 otherwise.
+ *  Returns: a callee-owned buffer containing the SHA hash digest.
+ *  The buffer is %GNET_SHA_HASH_LENGTH bytes long.
  *
  **/
-gint
-gnet_sha_equal (gconstpointer p1, gconstpointer p2)
+gchar*        	
+gnet_sha_get_digest (const GSHA* sha)
 {
-  GSHA* gshaa = (GSHA*) p1;
-  GSHA* gshab = (GSHA*) p2;
-  guint i;
-
-  for (i = 0; i < GNET_SHA_HASH_LENGTH; ++i)
-    if (gshaa->digest[i] != gshab->digest[i])
-      return 0;
-
-  return 1;
-}
-
-
-/**
- *  gnet_sha_hash
- *  @p: GSHA to get hash value of
- *
- *  Hash the GSHA hash value.  This is not the actual SHA hash, but a
- *  hash of this hash.
- *
- *  Returns: hash value.
- *
- **/
-guint
-gnet_sha_hash (gconstpointer p)
-{
-  const GSHA* gsha = (const GSHA*) p;
-  const guint* q;
-
-  g_return_val_if_fail (gsha, 0);
-
-  q = (const guint*) gsha->digest;
-
-  return (q[0] ^ q[1] ^ q[2] ^ q[3] ^ q[4]);
-}
-
-
-/**
- *  gnet_sha_get_digest:
- *  @gsha: #GSHA to get hash digest from
- *
- *  Get the SHA hash digest.  
- *
- *  Returns: buffer containing the SHA hash digest.  The buffer is
- *  GNET_SHA_HASH_LENGTH bytes long.  The #GSHA owns the buffer - do
- *  not free it.
- *
- **/
-guint8*        	
-gnet_sha_get_digest (const GSHA* gsha)
-{
-  g_return_val_if_fail (gsha, NULL);
+  g_return_val_if_fail (sha, NULL);
   
-  return (guint8*) gsha->digest;
+  return (gchar*) sha->digest;
 }
 
 
@@ -704,26 +655,26 @@ static gchar bits2hex[16] = { '0', '1', '2', '3',
 			      'c', 'd', 'e', 'f' };
 
 /**
- *  gnet_sha_get_string:
- *  @gsha: #GSHA to get hash from
+ *  gnet_sha_get_string
+ *  @sha: a #GSHA
  *
- *  Get a hash string.  
+ *  Get the digest represented a human-readable string.
  *
- *  Returns: Hexadecimal string representing the hash.  The string is
- *  of length 2 * %GNET_SHA_HASH_LENGTH and null terminated.  The
- *  caller must free the string.
+ *  Returns: a hexadecimal string representing the digest.  The string
+ *  is 2 * %GNET_SHA_HASH_LENGTH bytes long and NULL terminated.  The
+ *  string is caller owned.
  *
  **/
 gchar*          
-gnet_sha_get_string (const GSHA* gsha)
+gnet_sha_get_string (const GSHA* sha)
 {
   gchar* str;
 
-  g_return_val_if_fail (gsha, NULL);
+  g_return_val_if_fail (sha, NULL);
 
   str = g_new (gchar, GNET_SHA_HASH_LENGTH * 2 + 1);
 
-  gnet_sha_copy_string (gsha, str);
+  gnet_sha_copy_string (sha, str);
   str[GNET_SHA_HASH_LENGTH * 2] = '\0';
 
   return str;
@@ -733,25 +684,74 @@ gnet_sha_get_string (const GSHA* gsha)
 
 
 /**
- * gnet_sha_copy_string:
- * @gsha: #GSHA to get hash from
- * @buffer: Buffer of length of at least 2 * %GNET_SHA_HASH_LENGTH
+ * gnet_sha_copy_string
+ * @sha: a #GSHA
+ * @buffer: buffer at least 2 * %GNET_SHA_HASH_LENGTH bytes long
  *
- * Copy the hash string into the buffer.
+ * Copies the digest, represented as a string, into @buffer.  The
+ * string is not NULL terminated.
  * 
  **/
 void
-gnet_sha_copy_string (const GSHA* gsha, guchar* buffer)
+gnet_sha_copy_string (const GSHA* sha, gchar* buffer)
 {
   guint i;
 
-  g_return_if_fail (gsha);
+  g_return_if_fail (sha);
   g_return_if_fail (buffer);
 
   for (i = 0; i < GNET_SHA_HASH_LENGTH; ++i)
     {
-      buffer[i * 2]       = bits2hex[(gsha->digest[i] & 0xF0) >> 4];
-      buffer[(i * 2) + 1] = bits2hex[(gsha->digest[i] & 0x0F)     ];
+      buffer[i * 2]       = bits2hex[(sha->digest[i] & 0xF0) >> 4];
+      buffer[(i * 2) + 1] = bits2hex[(sha->digest[i] & 0x0F)     ];
     }
 }
 
+
+/**
+ *  gnet_sha_equal
+ *  @p1: a #GSHA.
+ *  @p2: another #GSHA.
+ *
+ *  Compares two #GSHA's for equality.
+ *
+ *  Returns: TRUE if they are equal; FALSE otherwise.
+ *
+ **/
+gboolean
+gnet_sha_equal (gconstpointer p1, gconstpointer p2)
+{
+  GSHA* shaa = (GSHA*) p1;
+  GSHA* shab = (GSHA*) p2;
+  guint i;
+
+  for (i = 0; i < GNET_SHA_HASH_LENGTH; ++i)
+    if (shaa->digest[i] != shab->digest[i])
+      return FALSE;
+
+  return TRUE;
+}
+
+
+/**
+ *  gnet_sha_hash
+ *  @p: a #GSHA
+ *
+ *  Creates a hash code for a #GMD5 for use with GHashTable.  This
+ *  hash value is not the same as the MD5 digest.
+ *
+ *  Returns: the hash code for @p.
+ *
+ **/
+guint
+gnet_sha_hash (gconstpointer p)
+{
+  const GSHA* sha = (const GSHA*) p;
+  const guint* q;
+
+  g_return_val_if_fail (sha, 0);
+
+  q = (const guint*) sha->digest;
+
+  return (q[0] ^ q[1] ^ q[2] ^ q[3] ^ q[4]);
+}
